import { Text, View } from "@tarojs/components"
import { memo, useMemo,  useState } from "react"
import styles  from './index.module.scss'
import classnames from "classnames";
import { formatDateTime } from "@/common/fotmat";
import { ORDER_STATUS } from "@/common/enum";

type List = {
    status: string,
    time: string,
    tag: string,
    desc: string,
    expire_time: string
}

type Param = {
    onRefresh?: () => void,
    orderInfo?: {
        logistics_details:List[], //订单状态列表
        payment_method: number, //支付方式
        status: number, //订单状态
    }
}

export default memo(({orderInfo = {logistics_details: [],payment_method: 0, status: 0}, onRefresh}:Param) => {
    
    const [showMore, setShowMore] = useState(false)
    const changeMore = () => {
        setShowMore(() => !showMore)
    }
    const dataList = useMemo(() => {
        return orderInfo.logistics_details?orderInfo?.logistics_details.reverse():[]
    }, [orderInfo.logistics_details])

    //订单状态枚举
    const {SaleorderstatusWaitingPrePayment} = ORDER_STATUS


    return (
        <>
            {(dataList?.length > 0)&&<View className={styles.order_flow_state}>
                <View className={classnames(styles.order_status_list, showMore&&styles.order_status_list_show)}>
                    {dataList.map((item, index) => <View className={styles.order_status_item}>
                        {(dataList.length > 1)&&<View className={classnames(styles.order_status_tail, (index == 0)&&styles.order_status_tail_end)}></View>}
                        {(dataList.length != (index + 1))&&<View className={styles.order_status_line}></View>}
                        <View className={styles.order_status_content}>
                            <View className={classnames(styles.order_status_title, (index == 0)&&styles.order_status_select)}>{item.status}</View>
                            <View className={classnames(styles.order_status_time, (index == 0)&&styles.order_status_select)}>{formatDateTime(item.time)}</View>
                        </View>
                        <Text className={classnames(styles.order_status_des, (index == 0)&&styles.order_status_des_select)}>{item.desc}</Text>
                    </View>)}
                </View>
                {(dataList.length > 2) && <View className={styles.more} onClick={() => changeMore()}>
                    <Text>{showMore&&'收起详情'||'点击查看详情'}</Text>
                    <Text className={classnames('iconfont icon-a-moreback', styles.miconfonts, showMore&&styles.open_miconfonts)}></Text>
                </View>}
            </View>}
        </>
    )
})
